user_defs_map

Function user_defs_map 

fn user_defs_map() -> &'static RwLock<HashMap<CrateNum, HashMap<String, DefSpec>>>
Per-crate user defs, registered from #[rapx::def_contract] attributes.

Keyed by CrateNum so that defs defined in one crate cannot leak into (or collide with) another crate analyzed in the same process. A crate’s own defs shadow builtin defs of the same name.